{% load i18n %}

{% if form.non_field_errors or form.save_error %}
    <div class="message is-danger" style="word-wrap: break-word;">
        <div class="message-body">
            {{ form.non_field_errors }}
            {% if form.save_error %}
                <p>{{ form.save_error }}</p>
                {% if form.save_error_id %}<span>{% translate 'Error ID' %}: {{ form.save_error_id }}</span>{% endif %}
            {% endif %}
        </div>
    </div>
{% endif %}
